==> members-feign-airport4-20241016.033357-7-sources.jar: com/bizvane/members/feign/service/MbrExtendFeign.java <==
package com.bizvane.members.feign.service;

import com.bizvane.members.feign.model.bo.*;
import com.bizvane.members.feign.model.vo.CouponDefinitionVO;
import com.bizvane.members.feign.model.vo.MbrExtendDefVO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.data.repository.query.Param;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

@FeignClient(value="${feign.client.members.name}",path="${feign.client.members.path}/mbrExtend")
@Api("会员扩展属性")
public interface MbrExtendFeign {

  @ApiOperation(value = "新增属性定义")
  @RequestMapping(value="/addDef", method = RequestMethod.POST)
  ResponseData<String> addDef(@RequestBody MbrExtendDefAddRequestParam param);

  @ApiOperation(value = "更新属性定义")
  @RequestMapping(value="/updateDef", method = RequestMethod.POST)
  ResponseData<Boolean> updateDef(@RequestBody MbrExtendDefUpdateRequestParam param);

  @ApiOperation(value = "列表查询")
  @RequestMapping(value="/listDef", method = RequestMethod.POST)
  PageInfo<MbrExtendDefVO> listDef(@RequestBody MbrExtendDefListRequestParam param);

  @ApiOperation(value = "属性定义详情")
  @RequestMapping(value="/detailDef", method = RequestMethod.POST)
  MbrExtendDefVO detailDef(@Param("mbrExtendDefCode") String mbrExtendDefCode);


}

==> members-feign-airport4-20241017.084208-13-sources.jar: com/bizvane/members/feign/service/MbrExtendFeign.java <==
package com.bizvane.members.feign.service;

import com.bizvane.members.feign.model.bo.*;
import com.bizvane.members.feign.model.vo.CouponDefinitionVO;
import com.bizvane.members.feign.model.vo.MbrExtendDefVO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.data.repository.query.Param;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

@FeignClient(value="${feign.client.members.name}",path="${feign.client.members.path}/mbrExtend")
@Api("会员扩展属性")
public interface MbrExtendFeign {

  @ApiOperation(value = "新增属性定义")
  @RequestMapping(value="/addDef", method = RequestMethod.POST)
  ResponseData<String> addDef(@RequestBody MbrExtendDefAddRequestParam param);

  @ApiOperation(value = "更新属性定义")
  @RequestMapping(value="/updateDef", method = RequestMethod.POST)
  ResponseData<Boolean> updateDef(@RequestBody MbrExtendDefUpdateRequestParam param);

  @ApiOperation(value = "列表查询")
  @RequestMapping(value="/listDef", method = RequestMethod.POST)
  PageInfo<MbrExtendDefVO> listDef(@RequestBody MbrExtendDefListRequestParam param);

  @ApiOperation(value = "属性定义详情")
  @RequestMapping(value="/detailDef", method = RequestMethod.POST)
  MbrExtendDefVO detailDef(@Param("mbrExtendDefCode") String mbrExtendDefCode);

  @ApiOperation(value = "删除属性定义")
  @RequestMapping(value="/deleteDef", method = RequestMethod.POST)
  ResponseData<Boolean> deleteDef(@RequestBody MbrExtendDefDeleteRequestParam param);

}
